@@ -1,4 +1,7 @@
 from json import loads
+import os
+
+print(os.getcwd())
 
 def nori(args):
     verb = None
